@@ -15,7 +15,7 @@ from importlib import import_module
 from akerbp.mlops.cdf.helpers import set_up_cdf_client
 from akerbp.mlops.deployment import helpers
 from akerbp.mlops.core import logger
-
+from akerbp.mlops.model_manager import set_up_model_artifact
 
 logging=logger.get_logger(name='MLOps')
 
@@ -42,7 +42,7 @@ def deploy(model_settings):
             model_code_folder = helpers.get_top_folder(model_file)
 
             if SERVICE_NAME == 'prediction':
-                model_id = helpers.set_up_model_artifact(
+                model_id = set_up_model_artifact(
                     model_artifact_folder, 
                     model_name
                 )
@@ -84,7 +84,6 @@ def deploy(model_settings):
                 model_artifact_folder=model_artifact_folder,
                 model_import_path=model_import_path,
                 model_code_folder=model_code_folder,
-                env=ENV,
                 model_id=model_id,
                 test_import_path=test_import_path
             )
@@ -115,7 +114,7 @@ def deploy(model_settings):
             logging.info(f"Run model and service tests")
             if model_test_file:
                 helpers.run_tests(model_test_file)
-                helpers.run_tests('akerbp.mlops.tests', path_type='module')
+                helpers.run_tests('akerbp.mlops.services', path_type='module')
             else:
                 logging.warning("Model test file is missing! " \
                                 "Didn't run tests")
