@@ -15,7 +15,7 @@ from pydantic import Json, BaseModel
 from akerbp.mlops.gc.helpers import access_secret_version
 from akerbp.mlops.core import logger
 SERVICE_NAME = os.getenv("SERVICE_NAME")
-service = import_module(f"akerbp.mlops.{SERVICE_NAME}.service").service
+service = import_module(f"akerbp.mlops.services.{SERVICE_NAME}").service
 
 logging=logger.get_logger()
 
